gchecky.model.order_state_change_notification_t

Package gchecky :: Module model :: Class order_state_change_notification_t |
[hide private]
[frames] | no frames]

# Class order_state_change_notification_t

source code

         object --+
                  |
          gxml.Node --+
                      |
          gxml.Document --+
                          |
    abstract_notification_t --+
                              |
                             order_state_change_notification_t

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``order-state-change-notification``'`` The document's unique xml tag name.
| new_fulfillment_order_state = `String:PATH(new-fulfillment-orde`...``
| new_financial_order_state = `String:PATH(new-financial-order-st`...``
| previous_financial_order_state = `String:PATH(previous-financia`...``
| previous_fulfillment_order_state = `String:PATH(previous-fulfil`...``
| reason = `String:PATH(reason):OPT`
| _fields = ``{``'``google_order_number``'``:` ID:PATH(google-order-number)`...`` list of meta-Fields of this class.
Inherited from `abstract_notification_t`: `google_order_number`, `serial_number`, `timestamp`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### new_fulfillment_order_state Value:
      String:PATH(new-fulfillment-order-state):REQ:VALS("REVIEWING","CHARGEA
      BLE","CHARGING","CHARGED","PAYMENT_DECLINED","CANCELLED","CANCELLED_BY
      _GOOGLE")

  ### new_financial_order_state Value:
      String:PATH(new-financial-order-state):REQ:VALS("NEW","PROCESSING","DE
      LIVERED","WILL_NOT_DELIVER")

  ### previous_financial_order_state Value:
      String:PATH(previous-financial-order-state):REQ:VALS("REVIEWING","CHAR
      GEABLE","CHARGING","CHARGED","PAYMENT_DECLINED","CANCELLED","CANCELLED
      _BY_GOOGLE")

  ### previous_fulfillment_order_state Value:
      String:PATH(previous-fulfillment-order-state):REQ:VALS("NEW","PROCESSI
      NG","DELIVERED","WILL_NOT_DELIVER")

  ### _fields list of meta-Fields of this class. Value:
      {'google_order_number': ID:PATH(google-order-number):REQ,
       'new_financial_order_state': String:PATH(new-financial-order-state):R
      EQ:VALS("NEW","PROCESSING","DELIVERED","WILL_NOT_DELIVER"),
       'new_fulfillment_order_state': String:PATH(new-fulfillment-order-stat
      e):REQ:VALS("REVIEWING","CHARGEABLE","CHARGING","CHARGED","PAYMENT_DEC
      LINED","CANCELLED","CANCELLED_BY_GOOGLE"),
       'previous_financial_order_state': String:PATH(previous-financial-orde
      r-state):REQ:VALS("REVIEWING","CHARGEABLE","CHARGING","CHARGED","PAYME
      ...